#!/usr/bin/env python3

import subprocess
import os
import platform
import sys

def clear_screen():
    if platform.system() == "Windows":
        os.system('cls')
    else:
        os.system('clear')

def run_command(command, real_time=False):
    try:
        if real_time:
            process = subprocess.Popen(command, shell=True)
            process.communicate()
        else:
            process = subprocess.Popen(command, shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
            output = process.communicate()[0]
            print(output.decode())
    except KeyboardInterrupt:
        print("\nOperazione interrotta dall'utente.")
        return
    except subprocess.CalledProcessError as e:
        print(f"Errore nell'esecuzione del comando: {e}")
        return

def get_input(prompt):
    try:
        return input(prompt)
    except KeyboardInterrupt:
        print("\nOperazione interrotta dall'utente.")
        sys.exit(0)

def show_active_ip():
    try:
        # Ottiene l'IP interno
        internal_ip_command = "ipconfig getifaddr en0 || ipconfig getifaddr en1"
        internal_ip = subprocess.check_output(internal_ip_command, shell=True).decode().strip()
        print(f"Indirizzo IP Locale Attivo: {internal_ip}")

        # Ottiene l'IP pubblico
        public_ip = subprocess.check_output("curl -s https://api.ipify.org", shell=True).decode().strip()
        print(f"Indirizzo IP Pubblico della Connessione: {public_ip}")
    except Exception as e:
        print(f"Impossibile recuperare l'indirizzo IP: {e}")

def main():
    commands = {
        "1": ("networkquality", "Misura qualità della connessione", False),
        "2": ("ping -c 4 {}", "Ping a un indirizzo", False),
        "3": ("traceroute {}", "Traceroute a un indirizzo", False),
        "4": ("top", "Visualizza i top processi (interrompi con CTRL+C)", True),
        "5": ("df -h", "Visualizza spazio su disco", False),
        "6": (show_active_ip, "Visualizza solo l'indirizzo IP attivo e l'IP pubblico", False),
        "7": ("dig {}", "Informazioni DNS per un indirizzo", False),
        "8": ("whois {}", "Informazioni WHOIS per un dominio", False),
        "9": ("nmap -F {}", "Scansiona le porte su un indirizzo", False),
        "0": ("system_profiler SPHardwareDataType", "Informazioni hardware del sistema", False),
        "q": ("", "Esci dal programma", False)
    }

    while True:
        clear_screen()
        print("\nQuale test/comando vuoi eseguire?")
        for key, value in commands.items():
            print(f"{key}: {value[1]}")
        
        choice = get_input("Scegli un'opzione: ")
        if choice == 'q':
            print("Uscita dal programma...")
            break
        if choice in commands and choice != 'q':
            cmd = commands[choice][0]
            if callable(cmd):
                clear_screen()
                print(f"Esecuzione {commands[choice][1]}...")
                cmd()
            else:
                if '{}' in cmd:
                    target = get_input(f"Inserisci l'indirizzo per {commands[choice][1]}: ")
                    cmd = cmd.format(target)
                clear_screen()
                print(f"Esecuzione {commands[choice][1]}...")
                run_command(cmd, commands[choice][2])
            get_input("\nPremi invio per continuare...")
        else:
            print("Opzione non valida, riprova.")
            get_input("Premi invio per continuare...")

if __name__ == "__main__":
    main()